/*
 * Copyright © 2022 Soren Stoutner <soren@stoutner.com>.
 *
 * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc>.
 *
 * Privacy Browser PC is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Privacy Browser PC is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Privacy Browser PC.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef BROWSERWINDOW_H
#define BROWSERWINDOW_H

// Application headers.
#include "views/BrowserView.h"

// KDE Frameworks headers.
#include <KConfigDialog>
#include <KXmlGuiWindow>

// Qt toolkit headers.
#include <QLabel>

class BrowserWindow : public KXmlGuiWindow
{
    // Include the Q_OBJECT macro.
    Q_OBJECT

public:
    // The default constructor.
    BrowserWindow();

private Q_SLOTS:
    // The private slots.
    void back() const;
    void fileNew() const;
    void forward() const;
    void getZoomFactorFromUser();
    void home() const;
    void loadUrlFromLineEdit(const QString &url) const;
    void refresh() const;
    void settingsConfigure();
    void updateDomainSettingsIndicator(const bool status) const;
    void updateOnTheFlySearchEngine(const QString &searchEngine) const;
    void updateOnTheFlyUserAgent(const QString &userAgent) const;
    void updateOnTheFlyZoomFactor(const double &zoomFactor);
    void updateSearchEngineLabel(const QString &searchEngineString) const;
    void updateUrlLineEdit(const QString &newUrl) const;
    void updateUserAgentLabel(const QString &userAgentDatabaseName) const;

private:
    // The private variables.
    QAction *backActionPointer;
    BrowserView *browserViewPointer;
    KConfigDialog *configDialogPointer;
    QPalette domainSettingsPalette;
    double currentZoomFactor;
    QAction *forwardActionPointer;
    QAction *homeActionPointer;
    QPalette noDomainSettingsPalette;
    QLabel *searchEngineLabelPointer;
    QAction *searchEngineMojeekActionPointer;
    QAction *searchEngineMonoclesActionPointer;
    QAction *searchEngineMetagerActionPointer;
    QAction *searchEngineGoogleActionPointer;
    QAction *searchEngineBingActionPointer;
    QAction *searchEngineYahooActionPointer;
    QAction *searchEngineCustomActionPointer;
    QAction *refreshActionPointer;
    QLabel *userAgentLabelPointer;
    QAction *userAgentPrivacyBrowserActionPointer;
    QAction *userAgentFirefoxLinuxActionPointer;
    QAction *userAgentChromiumLinuxActionPointer;
    QAction *userAgentFirefoxWindowsActionPointer;
    QAction *userAgentChromeWindowsActionPointer;
    QAction *userAgentEdgeWindowsActionPointer;
    QAction *userAgentSafariMacosActionPointer;
    QAction *userAgentCustomActionPointer;
    KLineEdit *urlLineEditPointer;
    QAction *zoomFactorActionPointer;
};
#endif
